@@ -1,4 +1,4 @@
-from typing import List, Optional, Dict, Any
+from typing import List, Optional, Dict, Any, Union
 
 from dataclasses import dataclass, field
 from code_loader.contract.enums import DatasetMetadataType, LeapDataType
@@ -63,7 +63,7 @@ class CustomLayerInstance:
 class PredictionTypeInstance:
     name: str
     labels: List[str]
-    channel_dim: Optional[int] = -1
+    channel_dim: int
 
 
 @dataclass
@@ -103,6 +103,8 @@ class BoundingBox:
     height: float  # value between [0, 1], represent the percentage according to the image size.
     confidence: float
     label: str
+    rotation: float = 0.0  # value between [0, 360], represent the degree of rotation.
+    metadata: Optional[Dict[str, Union[str, int, float]]] = None
 
 
 @dataclass
