@@ -9,8 +9,8 @@ from code_loader.contract.datasetclasses import SectionCallableInterface, InputH
     PreprocessHandler, VisualizerCallableInterface, CustomLossHandler, CustomCallableInterface, PredictionTypeHandler, \
     MetadataSectionCallableInterface, UnlabeledDataPreprocessHandler, CustomLayerHandler, MetricHandler, \
     CustomCallableInterfaceMultiArgs, ConfusionMatrixCallableInterfaceMultiArgs, VisualizerCallableReturnType, \
-    CustomMultipleReturnCallableInterfaceMultiArgs, DatasetBaseHandler, custom_latent_space_attribute
-from code_loader.contract.enums import LeapDataType, DataStateEnum, DataStateType
+    CustomMultipleReturnCallableInterfaceMultiArgs, DatasetBaseHandler, custom_latent_space_attribute, RawInputsForHeatmap
+from code_loader.contract.enums import LeapDataType, DataStateEnum, DataStateType, MetricDirection
 from code_loader.contract.responsedataclasses import DatasetTestResultPayload
 from code_loader.contract.visualizer_classes import map_leap_data_type_to_visualizer_class
 from code_loader.utils import to_numpy_return_wrapper, get_shape
@@ -50,10 +50,16 @@ class LeapBinder:
                        heatmap_visualizer: Optional[Callable[..., npt.NDArray[np.float32]]] = None) -> None:
         arg_names = inspect.getfullargspec(function)[0]
         if heatmap_visualizer:
-            if arg_names != inspect.getfullargspec(heatmap_visualizer)[0]:
-                raise Exception(
-                    f'The argument names of the heatmap visualizer callback must match the visualizer callback '
-                    f'{str(arg_names)}')
+            visualizer_arg_names_set = set(arg_names)
+            heatmap_visualizer_inspection = inspect.getfullargspec(heatmap_visualizer)
+            heatmap_arg_names_set = set(heatmap_visualizer_inspection[0])
+            if visualizer_arg_names_set != heatmap_arg_names_set:
+                arg_names_difference = set(inspect.getfullargspec(heatmap_visualizer)[0]).difference(set(arg_names))
+                if len(arg_names_difference) != 1 or \
+                        heatmap_visualizer_inspection.annotations[list(arg_names_difference)[0]] != RawInputsForHeatmap:
+                    raise Exception(
+                        f'The argument names of the heatmap visualizer callback must match the visualizer callback '
+                        f'{str(arg_names)}')
 
         if visualizer_type.value not in map_leap_data_type_to_visualizer_class:
             raise Exception(
@@ -103,9 +109,10 @@ class LeapBinder:
                           function: Union[CustomCallableInterfaceMultiArgs,
                           CustomMultipleReturnCallableInterfaceMultiArgs,
                           ConfusionMatrixCallableInterfaceMultiArgs],
-                          name: str) -> None:
+                          name: str,
+                          direction: Optional[MetricDirection] = MetricDirection.Downward) -> None:
         arg_names = inspect.getfullargspec(function)[0]
-        self.setup_container.metrics.append(MetricHandler(name, function, arg_names))
+        self.setup_container.metrics.append(MetricHandler(name, function, arg_names, direction))
 
     def add_prediction(self, name: str, labels: List[str], channel_dim: int = -1) -> None:
         self.setup_container.prediction_types.append(PredictionTypeHandler(name, labels, channel_dim))
